@@ -49,6 +49,8 @@ TG4RunConfiguration::TG4RunConfiguration(const TString& userGeometry,
     fSpecialControls(false),
     fSpecialCuts(false),
     fSpecialCutsOld(false),
+    fUseOfG4Scoring(false),
+    fUseOfScoreWeighting(false),
     fAGDDMessenger(0),
     fGDMLMessenger(0),
     fParameters()
