@@ -45,6 +45,9 @@
 #include <G4RunManager.hh>
 #endif
 
+#include <G4ScoringManager.hh>
+#include <G4VScoringMesh.hh>
+
 #include <G4UIExecutive.hh>
 #include <G4UImanager.hh>
 #include <G4UIsession.hh>
@@ -128,7 +131,10 @@ TG4RunManager::TG4RunManager(
 
   if (isMaster) {
     fgMasterInstance = this;
-
+    if (runConfiguration->IsUseOfG4Scoring()) {
+      // activate G4 command-line scoring
+      G4ScoringManager::GetScoringManager();
+    }
     // create and configure G4 run manager
     ConfigureRunManager();
   }
@@ -468,6 +474,12 @@ void TG4RunManager::LateInitialize()
   TG4PhysicsManager::Instance()->SetProcessActivation();
   TG4PhysicsManager::Instance()->RetrieveOpBoundaryProcess();
 
+  // late initialize SD manager
+  // (needed only if user sets score weight calculator)
+  if (fRunConfiguration->IsUseOfScoreWeighting()) {
+    TG4SDManager::Instance()->LateInitialize(fRunConfiguration->GetScoreWeightCalculator());
+  }
+
   // late initialize step manager
   TG4StepManager::Instance()->LateInitialize();
 
@@ -601,6 +613,16 @@ Bool_t TG4RunManager::FinishRun()
   G4bool result = !TG4SDServices::Instance()->GetIsStopRun();
   TG4SDServices::Instance()->SetIsStopRun(false);
 
+  if (fRunConfiguration->IsUseOfG4Scoring()) {
+    // Dump all scoring meshes in file
+    auto g4ScoringManager = G4ScoringManager::GetScoringManager();
+    for (std::size_t i = 0; i < g4ScoringManager->GetNumberOfMesh(); ++i) {
+      auto meshName = g4ScoringManager->GetMesh(i)->GetWorldName();
+      auto fileName = meshName + ".txt";
+      g4ScoringManager->DumpAllQuantitiesToFile(meshName, fileName);
+    }
+  }
+
   return result;
 }
 
